function m_cfgs(action, aux)
%M_CFGS  - MAVIS configure spatial window support

%	branch by action...

switch action,

%-----------------------------------------------------------------------------
%	BLOBSIZE:  change displayed blob size (aux = 1 by slider; 2 by field)

	case 'BLOBSIZE',
		cfgState = get(gcbf, 'UserData');
		switch aux,
			case 1,			% slider
				v = get(gcbo, 'Value');
				set(get(gcbo, 'UserData'), 'String', sixdig(v));
			case 2,			% field
				v = str2num(get(gcbo, 'String'));
				vv = v;
				if isempty(v) | v < 1,
					v = 1;
				elseif v > 50,
					v = 50;
				end;
				if v ~= vv, set(gcbo, 'String', sixdig(v)); end;
				set(get(gcbo, 'UserData'), 'Value', v);
		end;
		spatState = get(cfgState.SPATWIN, 'UserData');
		spatState.BLOBSIZE = v;
		set(cfgState.SPATWIN, 'UserData', spatState);
		set(spatState.BLOBS, 'MarkerSize', v);
		
	
%-----------------------------------------------------------------------------
%	CHGDIR:  change xfer direction (aux > 0: loaded ==> linked; < 0:  loaded <== linked )

	case 'CHGDIR',
		xfer = get(gcbo, 'UserData');		% xfer button
		if get(xfer, 'UserData') == aux, return; end;	% already set
		if aux > 0,
			set(xfer, 'UserData', 1, 'String', '>');
		else,
			set(xfer, 'UserData', -1, 'String', '<');
		end;
		
		
%-----------------------------------------------------------------------------
%	CHGMODE:  change link mode

	case 'CHGMODE',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		spatState.LINKMODE = get(gcbo, 'Value');
		set(cfgState.SPATWIN, 'UserData', spatState);
 		m_spat('INIT', get(spatState.GUI, 'UserData'));
 		figure(cfgState.SPATWIN);
		
	
%-----------------------------------------------------------------------------
%	CLOSE:  restore spatial window state on cancel

	case 'CLOSE',
		
		if ~aux,		% on cancel (restore prev state)
			cfgState = get(gcbf, 'UserData');
			spatState = get(cfgState.SPATWIN, 'UserData');
			switch cfgState.MODE,
				case 'VIEW',
					ds = ['normal';'revers'];
					di = cfgState.SAVEDIRS+1;
					set(spatState.AXIS, ...
						'View', cfgState.SAVEVIEW, ...
						'XDir', ds(di(1)), ...
						'YDir', ds(di(2)), ...
						'ZDir', ds(di(3)));
					spatState.PREFVIEW = cfgState.SAVEDEFVIEW;
				case 'MODE',
					global D_NOERASE;
					spatState.BLOBSIZE = cfgState.SAVESIZE;
					spatState.BLOBTYPE = cfgState.SAVETYPE;
					spatState.MODE = cfgState.SAVEMODE;
					spatState.GRID = cfgState.SAVEGRID;
					spatState.PALATE = cfgState.SAVEPAL;
					spatState.IMAGE = cfgState.SAVEIMG;
					set(cfgState.SPATWIN, 'UserData', spatState);
					if spatState.MODE == D_NOERASE, mode = 'none'; else, mode = 'xor'; end;
					set(spatState.BLOBS, ...
							'Marker', spatState.BLOBTYPE, ...
							'MarkerSize', spatState.BLOBSIZE, ...
							'EraseMode', mode);
					if spatState.GRID, mode = 'on'; else, mode = 'off'; end;
					set(spatState.AXIS, 'Xgrid', mode, 'YGrid', mode, 'ZGrid', mode);
					set(gcbf, 'Visible', 'off');
					m_spat('INIT', get(spatState.GUI, 'UserData'));
					figure(cfgState.SPATWIN);
				case 'LINKING',
					spatState.LINKMODE = cfgState.SAVEMODE;
					spatState.LINKMAP = cfgState.SAVEMAP;
					set(cfgState.SPATWIN, 'UserData', spatState);
					set(gcbf, 'Visible', 'off');
					m_spat('INIT', get(spatState.GUI, 'UserData'));
					figure(cfgState.SPATWIN);
				case 'SCALING',
					spatState.AUTOSCALE = cfgState.SAVEAUTO;
					spatState.SPREAD = cfgState.SAVESPREAD;
					spatState.OFFSETS = cfgState.SAVEOFFSETS;
					set(cfgState.SPATWIN, 'UserData', spatState);
					set(gcbf, 'Visible', 'off');
					m_spat('INIT', get(spatState.GUI, 'UserData'));
					figure(cfgState.SPATWIN);
			end;
		end;
		delete(gcbf);
		
	
%-----------------------------------------------------------------------------
%	EDITVIEW:  change view by edit field entry (aux 1 = az, 2 = el)

	case 'EDITVIEW',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		v = get(spatState.AXIS, 'View');
		n = str2num(get(gcbo, 'String'));
		if n > 180 | n < -180, 
			n = rem(n,180);
			set(gcbo, 'String', sixdig(n));	
		end;
		v(aux) = n;
		set(spatState.AXIS, 'View', v);
		set(cfgState.SLIDERH(aux), 'Value', v(aux));
		
	
%-----------------------------------------------------------------------------
%	GRID:  toggle displayed grid

	case 'GRID',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		spatState.GRID = get(gcbo, 'Value');
		set(cfgState.SPATWIN, 'UserData', spatState);
		if spatState.GRID, mode = 'on'; else, mode = 'off'; end;
		set(spatState.AXIS, 'Xgrid', mode, 'YGrid', mode, 'ZGrid', mode);
		
		
%-----------------------------------------------------------------------------
%	INITialize:  aux is specifier

	case 'INIT',
		set(0,'ShowHiddenHandles', 'on');
		spatWin = findobj('Tag', 'SPAT');
		set(0,'ShowHiddenHandles', 'off');
		spatState = get(spatWin, 'UserData');
		if ~spatState.INITIALIZED, return; end;
		figure(spatWin);
 		figPos = get(0, 'ScreenSize');
		if strncmp(computer, 'SGI', 3), as = 'left'; else, as = 'right'; end;	% SGI bug:  doesn't like right alignment
		
		switch aux,

% set viewpoint
			case 'VIEW', 
				width = 275; 
				height = 150;
				figPos = [figPos(1)+(figPos(3)-width)/2, figPos(2)+(figPos(4)-height)/2, width, height];
				[az, el] = view;
				dirs = [strncmp(get(spatState.AXIS,'xdir'),'r',1), ...
						strncmp(get(spatState.AXIS,'ydir'),'r',2), ...
						strncmp(get(spatState.AXIS,'zdir'),'r',3)]; 
				cfg = dialog('Name', 'Set Viewpoint', ...
					'Position', figPos, ...
					'ButtonDownFcn', '', ...
					'CreateFcn', 'm_traj(''CURSOR'', ''HIDE'');', ...
					'DeleteFcn', 'm_traj(''CURSOR'', ''SHOW'');', ...
					'CloseRequestFcn', 'm_cfgs(''CLOSE'',0);');
				uicontrol(cfg, ...		% azimuth
					'Position', [10 115 20 17], ...
					'HorizontalAlignment', as, ...
					'String','Az:', ...
					'Style','text');
				azS = uicontrol(cfg, ...
					'Position',[35 115 165 20], ...
					'Style','slider', ...
					'Value', az, ...
					'Min', -180, 'Max', 180, ...
					'Callback', 'm_cfgs(''SLIDEVIEW'',1);');
				azF = uicontrol(cfg, ...
					'Position',[209 115 50 20], ...
					'Style','edit', ...
					'HorizontalAlignment', 'left', ...
					'String', sixdig(az), ...
					'Callback', 'm_cfgs(''EDITVIEW'',1);');
					
				uicontrol(cfg, ...		% elevation
					'Position', [10 85 20 17], ...
					'HorizontalAlignment', as, ...
					'String','El:', ...
					'Style','text');
				elS = uicontrol(cfg, ...
					'Position',[35 85 165 20], ...
					'Style','slider', ...
					'Value', el, ...
					'Min', -180, 'Max', 180, ...
					'Callback', 'm_cfgs(''SLIDEVIEW'',2);');
				elF = uicontrol(cfg, ...
					'Position',[209 85 50 20], ...
					'Style','edit', ...
					'HorizontalAlignment', 'left', ...
					'String', sixdig(el), ...
					'Callback', 'm_cfgs(''EDITVIEW'',2);');

				uicontrol(cfg, ...		% invert
					'Position', [45 51 55 17], ...
					'HorizontalAlignment', as, ...
					'String','Invert:', ...
					'Style','text');
				uicontrol(cfg, ...
					'Position',[105 52 37 20], ...
					'String','X', ...
					'Value', dirs(1), ...
					'Style','checkbox', ...
					'Callback', 'm_cfgs(''INVERT'',''X'');');
				uicontrol(cfg, ...
					'Position',[142 52 37 20], ...
					'String','Y', ...
					'Value', dirs(2), ...
					'Style','checkbox', ...
					'Callback', 'm_cfgs(''INVERT'',''Y'');');
				uicontrol(cfg, ...
					'Position',[179 52 37 20], ...
					'String','Z', ...
					'Value', dirs(3), ...
					'Style','checkbox', ...
					'Callback', 'm_cfgs(''INVERT'',''Z'');');

				uicontrol(cfg, ...		% make default
					'Position',[165 13 95 25], ...
					'String','Make Default', ...
					'Callback', 'm_cfgs SETDEFVIEW;');
					
				cfgState = struct('MODE', aux, ...
								'SPATWIN', spatWin, ...
								'VIEWFH', [azF elF], ...
								'SLIDERH', [azS elS], ...
								'SAVEDIRS', dirs, ...
								'SAVEVIEW', [az el], ...
								'SAVEDEFVIEW', spatState.PREFVIEW);

% set display mode
			case 'MODE', 
				width = 275; 
				height = 180;
				figPos = [figPos(1)+(figPos(3)-width)/2, figPos(2)+(figPos(4)-height)/2, width, height];
				cfgState = struct('MODE', aux, ...
								'SPATWIN', spatWin, ...
								'BLOBLIST', char({'+';'o';'*';'.';'x';'square';'diamond';'v';'^';'>';'<';'pentagram';'hexagram'}), ...
								'SAVESIZE', spatState.BLOBSIZE, ...
								'SAVETYPE', spatState.BLOBTYPE, ...
								'SAVEMODE', spatState.MODE, ...
								'SAVEGRID', spatState.GRID, ...
								'SAVEPAL', spatState.PALATE, ...
								'SAVEIMG', spatState.IMAGE);
				cfg = dialog('Name', 'Set Display Options', ...
					'Position', figPos, ...
					'ButtonDownFcn', '', ...
					'CreateFcn', 'm_traj(''CURSOR'', ''HIDE'');', ...
					'DeleteFcn', 'm_traj(''CURSOR'', ''SHOW'');', ...
					'CloseRequestFcn', 'm_cfgs(''CLOSE'',0);');
					
				uicontrol(cfg, ...		% mode
					'Position', [10 150 75 17], ...
					'HorizontalAlignment', as, ...
					'String','Display mode:', ...
					'Style','text');
				uicontrol(cfg, ...
					'Position',[90 148 115 20], ...
					'HorizontalAlignment', 'left', ...
					'String','Blobs|No erasure|Track Velocity|History Ghosts', ...
					'Value', spatState.MODE, ...
					'Style','popupmenu', ...
					'Callback', 'm_cfgs SETMODE;');
				uicontrol(cfg, ...
					'Position',[210 148 50 20], ...
					'HorizontalAlignment', 'left', ...
					'String', cfgState.BLOBLIST, ...
					'Value', strmatch(spatState.BLOBTYPE, cfgState.BLOBLIST), ...
					'Style','popupmenu', ...
					'Callback', 'm_cfgs SETBLOB;');

				uicontrol(cfg, ...		% blob size
					'Position', [10 120 75 17], ...
					'HorizontalAlignment', as, ...
					'String','Blob size:', ...
					'Style','text');
				ss = uicontrol(cfg, ...
					'Position',[90 120 110 20], ...
					'Style','slider', ...
					'Value', spatState.BLOBSIZE, ...
					'Min', 1, 'Max', 50, ...
					'Callback', 'm_cfgs(''BLOBSIZE'', 1);');
				sf = uicontrol(cfg, ...
					'Position',[209 120 50 20], ...
					'Style','edit', ...
					'String', sixdig(spatState.BLOBSIZE), ...
					'HorizontalAlignment', 'left', ...
					'Userdata', ss, ...
					'Callback', 'm_cfgs(''BLOBSIZE'', 2);');
				set(ss, 'Userdata', sf);

				uicontrol(cfg, ...		% grid
					'Position',[15 90 85 20], ...
					'String','show grid', ...
					'Value', spatState.GRID, ...
					'Style','checkbox', ...
					'Callback', 'm_cfgs GRID;');

				if isunix, s = 'palate'; else, s = 'palate trace'; end;
				uicontrol(cfg, ...		% palate trace
					'Position',[105 90 75 20], ...
					'String', s, ...
					'Value', spatState.PALATE.DISPLAY, ...
					'Style','checkbox', ...
					'Callback', 'm_cfgs TOGPAL;');
				uicontrol(cfg, ...
					'Position',[189 90 70 20], ...
					'Style','edit', ...
					'String', spatState.PALATE.NAME, ...
					'HorizontalAlignment', 'left', ...
					'Callback', 'eval([''m_cfgs(''''LOADPAL'''', '', get(gcbo, ''String''), '')''],''m_cfgs LOADPAL'');');

				if isunix, s = 'img'; else, s = 'image'; end;
				uicontrol(cfg, ...		% image
					'Position',[15 60 50 20], ...
					'String', s, ...
					'Value', spatState.IMAGE.DISPLAY, ...
					'Style','checkbox', ...
					'Callback', 'm_cfgs TOGIMG;');
				uicontrol(cfg, ...
					'Position',[70 60 70 20], ...
					'Style','edit', ...
					'String', spatState.IMAGE.NAME, ...
					'HorizontalAlignment', 'left', ...
					'Callback', 'eval([''m_cfgs(''''LOADIMG'''', '', get(gcbo, ''String''), '')''],''m_cfgs LOADIMG'');');
				uicontrol(cfg, ...
					'Position', [145 60 50 17], ...
					'HorizontalAlignment', as, ...
					'String','pix/mm:', ...
					'Style','text');
				uicontrol(cfg, ...
					'Position',[199 60 60 20], ...
					'Style','edit', ...
					'String', sixdig(spatState.IMAGE.PIXPERMM), ...
					'HorizontalAlignment', 'left', ...
					'Callback', 'm_cfgs SETPPM;');

% set linking
			case 'LINKING', 
				width = 275; 
				height = 180;
				figPos = [figPos(1)+(figPos(3)-width)/2, figPos(2)+(figPos(4)-height)/2, width, height];
				state = get(spatState.GUI, 'UserData');
				linkedIndex = spatState.LINKMAP;
				loadedIndex = setdiff(spatState.PLOTMAP, linkedIndex);
				if isempty(loadedIndex),
					loadedNames = '';
				else,
					loadedNames = state.DATA(loadedIndex);
					loadedNames = {loadedNames.NAME};
				end;
				if isempty(linkedIndex),
					linkedNames = '';
				else,
					linkedNames = state.DATA(linkedIndex);
					linkedNames = {linkedNames.NAME};
				end;
				cfgState = struct('MODE', aux, ...
								'SPATWIN', spatWin, ...
								'SAVEMODE', spatState.LINKMODE, ...
								'SAVEMAP', spatState.LINKMAP);
				cfg = dialog('Name', 'Set Linking', ...
					'Position', figPos, ...
					'ButtonDownFcn', '', ...
					'CreateFcn', 'm_traj(''CURSOR'', ''HIDE'');', ...
					'DeleteFcn', 'm_traj(''CURSOR'', ''SHOW'');', ...
					'CloseRequestFcn', 'm_cfgs(''CLOSE'',0);');

				xfer = uicontrol(cfg, ... 	% xfer
					'Position',[127 113 20 20], ...
					'String','>', ...
					'UserData', 1, ...
					'Callback', 'm_cfgs XFER;');
					
				uicontrol(cfg, ...			% loaded (displayed)
					'Style', 'text', ...
					'HorizontalAlignment','left', ...
					'String', 'Displayed', ...
					'Position', [30 152 60 17]);
				cfgState.LOADED = uicontrol(cfg, ...
					'Position',[20 95 90 56], ...
					'String', loadedNames, ...	
					'ListBoxTop', 1, ...
					'Style','listbox', ...
					'Max', 2, ...
					'Value', [], ...
					'UserData', xfer, ...
					'Callback', 'm_cfgs(''CHGDIR'',1);');
						
				uicontrol(cfg, ...			% linked
					'Style', 'text', ...
					'HorizontalAlignment','left', ...
					'String', 'Linked', ...
					'Position', [175 152 60 17]);
				cfgState.LINKED = uicontrol(cfg, ...
					'Position',[165 95 90 56], ...	
					'String', linkedNames, ...	
					'Style','listbox', ...
					'Max', 2, ...
					'Value', [], ...
					'UserData', xfer, ...
					'Callback', 'm_cfgs(''CHGDIR'',-1);');
					
				uicontrol(cfg, ...			% linking
					'Style', 'text', ...
					'HorizontalAlignment', as, ...
					'String', 'Linking:', ...
					'Position', [20 57 60 17]);
				uicontrol(cfg, ...
					'Position',[90 55 140 20], ...
					'HorizontalAlignment', 'left', ...
					'String','Off|Lines (open)|Lines (closed)|Natural Spline', ...
					'Value', spatState.LINKMODE, ...
					'Style','popupmenu', ...
					'Callback', 'm_cfgs CHGMODE;');
					
					
% set scaling
			case 'SCALING', 
				width = 290; 
				height = 140;
				figPos = [figPos(1)+(figPos(3)-width)/2, figPos(2)+(figPos(4)-height)/2, width, height];
				cfgState = struct('MODE', aux, ...
								'SPATWIN', spatWin, ...
								'SAVEAUTO', spatState.AUTOSCALE, ...
								'SAVESPREAD', spatState.SPREAD, ...
								'SAVEOFFSETS', spatState.OFFSETS);
				cfg = dialog('Name', 'Set Scaling', ...
					'Position', figPos, ...
					'ButtonDownFcn', '', ...
					'CreateFcn', 'm_traj(''CURSOR'', ''HIDE'');', ...
					'DeleteFcn', 'm_traj(''CURSOR'', ''SHOW'');', ...
					'CloseRequestFcn', 'm_cfgs(''CLOSE'',0);');

				uicontrol(cfg, ...		% spread
					'Style', 'text', ...
					'HorizontalAlignment', as, ...
					'String', 'Scale:', ...
					'Position', [10 99 40 17]);
				if isunix, pos = [51 100 53 20]; else, pos = [55 100 50 20]; end;
				cfgState.AUTO = uicontrol(cfg, ...
					'Position', pos, ...
					'String','Auto', ...
					'Style','radiobutton', ...
					'Value', spatState.AUTOSCALE, ...
					'Callback', 'set(gcbo,''Value'',1);set(get(gcbo,''UserData''),''Value'',~get(gcbo,''Value''));');
				if isunix, pos = [105 100 58 20]; else, pos = [110 100 50 20]; end;
				cfgState.FIXED = uicontrol(cfg, ...
					'Position', pos, ...
					'String','Fixed', ...
					'Style','radiobutton', ...
					'Value', ~spatState.AUTOSCALE, ...
					'UserData', cfgState.AUTO, ...
					'Callback', 'set(gcbo,''Value'',1);set(get(gcbo,''UserData''),''Value'',~get(gcbo,''Value''));');
				set(cfgState.AUTO, 'UserData', cfgState.FIXED);
				if isunix, pos = [164 99 50 17]; else, pos = [160 99 50 17]; end;
				uicontrol(cfg, ...
					'Style', 'text', ...
					'HorizontalAlignment', as, ...
					'String', 'Spread:', ...
					'Position', pos);
				cfgState.SPREAD = uicontrol(cfg, ...
					'Style', 'edit', ...
					'HorizontalAlignment', 'left', ...
					'Position', [215 100 60 20], ...
					'String', sixdig(spatState.SPREAD));

				if isunix, s = 'Offset:'; else, s = 'Offset (XYZ):'; end;
				uicontrol(cfg, ...		% offset
					'Style', 'text', ...
					'HorizontalAlignment', as, ...
					'String', s, ...
					'Position', [10 60 70 17]);
				cfgState.OFFSETS(1) = uicontrol(cfg, ...
					'Style', 'edit', ...
					'HorizontalAlignment', 'left', ...
					'Position', [85 60 60 20], ...
					'String', sixdig(spatState.OFFSETS(1)));
				cfgState.OFFSETS(2) = uicontrol(cfg, ...
					'Style', 'edit', ...
					'HorizontalAlignment', 'left', ...
					'Position', [150 60 60 20], ...
					'String', sixdig(spatState.OFFSETS(2)));
				cfgState.OFFSETS(3) = uicontrol(cfg, ...
					'Style', 'edit', ...
					'HorizontalAlignment', 'left', ...
					'Position', [215 60 60 20], ...
					'String', sixdig(spatState.OFFSETS(3)));

				uicontrol(cfg, ...		% apply
					'Position',[width/2-30 13 60 25], ...
					'String','Apply', ...
					'Callback','m_cfgs(''SCALING'',0);');

% error				
			otherwise,
				error(['M_CFGS:  unknown init option (', aux, ')']);
				
		end;

% OK, cancel buttons
		width = width / 2;
		switch aux,
			case 'SCALING',
				x1 = width-110;
				x2 = width+50;
				oks = 'm_cfgs(''SCALING'',1);';
			case 'VIEW',
				x1 = 15;
				x2 = 90;
				oks = 'm_cfgs(''CLOSE'',1);';
			otherwise,
				x1 = width-80;
				x2 = width+20;
				oks = 'm_cfgs(''CLOSE'',1);';
		end;
		uicontrol(cfg, ...
			'Position',[x1 13 60 25], ...
			'String','OK', ...
			'Callback',oks);
		uicontrol(cfg, ...
			'Position',[x2 13 60 25], ...
			'String','Cancel', ...
			'Callback','m_cfgs(''CLOSE'',0);');
			
% save state
		set(cfg, 'UserData', cfgState, 'Tag', 'CONFIG');

		
%-----------------------------------------------------------------------------
%	INVERT:  reverse axis orientation

	case 'INVERT',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		p = [aux,'dir'];
		dir = get(spatState.AXIS, p);
		if strcmp(dir, 'normal'),
			dir = 'reverse';
		else
			dir = 'normal';
		end;
		set(spatState.AXIS, p, dir);
		
	
%-----------------------------------------------------------------------------
%	LOADIMG:  load image data from field specified string

	case 'LOADIMG',
		if nargin == 1,		% clear data (empty or invalid field)
			cfgState = get(gcbf, 'UserData');
			spatState = get(cfgState.SPATWIN, 'UserData');
			spatState.IMAGE.DATA = [];
			set(cfgState.SPATWIN, 'UserData', spatState);
			m_spat('INIT', get(spatState.GUI, 'UserData'));
			figure(cfgState.SPATWIN);
			return;
		end;
		s = warning; warning off; eval(['global ', inputname(2)]); warning(s);
		m_gui('LOADIMG', aux, inputname(2));
		cfgState = get(gcbf, 'UserData');
 		figure(cfgState.SPATWIN);
		
		
%-----------------------------------------------------------------------------
%	LOADPAL:  load palate trace data from field specified string

	case 'LOADPAL',
		if nargin == 1,		% clear data (empty or invalid field)
			cfgState = get(gcbf, 'UserData');
			spatState = get(cfgState.SPATWIN, 'UserData');
			spatState.PALATE.DATA = [];
			set(cfgState.SPATWIN, 'UserData', spatState);
			m_spat('INIT', get(spatState.GUI, 'UserData'));
			figure(cfgState.SPATWIN);
			return;
		end;
		s = warning; warning off; eval(['global ', inputname(2)]); warning(s);
		m_gui('LOADPAL', aux, inputname(2));
		cfgState = get(gcbf, 'UserData');
 		figure(cfgState.SPATWIN);
		
		
%-----------------------------------------------------------------------------
%	SCALING:  update scaling (aux = 0 apply, = 1 OK)

	case 'SCALING',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		spatState.AUTOSCALE = get(cfgState.AUTO, 'Value');
		if ~spatState.AUTOSCALE,
			v = str2num(get(cfgState.SPREAD, 'String'));
			if isempty(v) | v <= 0,
				set(warndlg('specified spread is invalid', ''), 'WindowStyle', 'modal');
				return;
			else,
				spatState.SPREAD = v;
			end;
			for i = 1 : 3,
				v = str2num(get(cfgState.OFFSETS(i), 'String'));
				if isempty(v), v = 0; end;
				spatState.OFFSETS(i) = v;
			end;
		end;
		set(cfgState.SPATWIN, 'UserData', spatState);
		if aux, set(gcbf, 'Visible', 'off'); end;
		m_spat('INIT', get(spatState.GUI, 'UserData'));
		figure(cfgState.SPATWIN);
		if aux, m_cfgs('CLOSE', 1); end;
		
	
%-----------------------------------------------------------------------------
%	SETBLOB:  set display marker

	case 'SETBLOB',
		cfgState = get(gcbf, 'UserData');
		newType = deblank(cfgState.BLOBLIST(get(gcbo, 'Value'),:));
		spatState = get(cfgState.SPATWIN, 'Userdata');
		spatState.BLOBTYPE = newType;
		set(cfgState.SPATWIN, 'Userdata', spatState);
		set(spatState.BLOBS, 'Marker', newType);
	
	
%-----------------------------------------------------------------------------
%	SETDEFVIEW:  set preferred view

	case 'SETDEFVIEW',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'Userdata');
		spatState.PREFVIEW = [get(cfgState.SLIDERH(1), 'Value') get(cfgState.SLIDERH(2), 'Value')];
		set(cfgState.SPATWIN, 'Userdata', spatState);
	
	
%-----------------------------------------------------------------------------
%	SETMODE:  set display mode

	case 'SETMODE',
		global D_NOERASE D_VELOCI
		cfgState = get(gcbf, 'UserData');
		mode = get(gcbo, 'Value');
		spatState = get(cfgState.SPATWIN, 'Userdata');
		oldMode = spatState.MODE;
		if oldMode == mode, return; end;
		spatState.MODE = mode;
		set(cfgState.SPATWIN, 'Userdata', spatState);
		m_spat('INIT', get(spatState.GUI, 'UserData'));
		figure(cfgState.SPATWIN);
				
		
%-----------------------------------------------------------------------------
%	SETPPM:  set pixpermm from field

	case 'SETPPM',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		v = str2num(get(gcbo, 'String'));
		if isempty(v) | v <= 0, 
			v = 1;
			set(gcbo, 'String', 1);
		end;
		spatState.IMAGE.PIXPERMM = v;
		set(cfgState.SPATWIN, 'UserData', spatState);
 		m_spat('INIT', get(spatState.GUI, 'UserData'));
 		figure(cfgState.SPATWIN);
		
		
%-----------------------------------------------------------------------------
%	SLIDEVIEW:  change view by slider (aux 1 = az, 2 = el)

	case 'SLIDEVIEW',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		v = get(spatState.AXIS, 'View');
		v(aux) = get(gcbo, 'Value');
		set(spatState.AXIS, 'View', v);
		set(cfgState.VIEWFH(aux), 'String', sixdig(v(aux)));
		
	
%-----------------------------------------------------------------------------
%	TOGPAL:  toggle displayed palate trace

	case 'TOGPAL',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		spatState.PALATE.DISPLAY = get(gcbo, 'Value');
		set(cfgState.SPATWIN, 'UserData', spatState);
 		m_spat('INIT', get(spatState.GUI, 'UserData'));
 		figure(cfgState.SPATWIN);
		
		
%-----------------------------------------------------------------------------
%	TOGIMG:  toggle displayed image

	case 'TOGIMG',
		cfgState = get(gcbf, 'UserData');
		spatState = get(cfgState.SPATWIN, 'UserData');
		spatState.IMAGE.DISPLAY = get(gcbo, 'Value');
		set(cfgState.SPATWIN, 'UserData', spatState);
 		m_spat('INIT', get(spatState.GUI, 'UserData'));
 		figure(cfgState.SPATWIN);
		
		
%-----------------------------------------------------------------------------
%	XFER:  transfer list elements

	case 'XFER',
% transfer selected items between lists
		cfgState = get(gcbf, 'UserData');
		xferDir = get(gcbo, 'UserData');
		if xferDir > 0,
			fromH = cfgState.LOADED;
			toH = cfgState.LINKED;
		else,
			fromH = cfgState.LINKED;
			toH = cfgState.LOADED;
		end;
		xi = get(fromH, 'Value');	% selected indices
		fromList = cellstr(get(fromH, 'String'));
		if isempty(fromList), return; end;
		toList = cellstr(get(toH, 'String'));
		ki = setdiff([1:length(fromList)], xi);
		if isempty(toList{1}),
			toList = fromList(xi);
		else,
			toList = [toList ; fromList(xi)];
		end;
		if isempty(ki),
			fromList = [];
		else,
			fromList = fromList(ki);
		end;
		set(fromH, 'String', fromList, 'Value', []);
		set(toH, 'String', toList, 'Value', []);
		
% update the link map
		spatState = get(cfgState.SPATWIN, 'UserData');
		state = get(spatState.GUI, 'UserData');
		linkedList = cellstr(get(cfgState.LINKED, 'String'));
		if isempty(linkedList{1}),
			linkMap = [];
		else,
			names = state.DATA(2:end);		% don't dupe framing data
			names = char({names.NAME});
			linkMap = zeros(1, length(linkedList));
			for i = 1 : length(linkedList),
				linkMap(i) = strmatch(char(linkedList(i)), names, 'exact') + 1;	% adjust for framing data
			end;
		end;
		spatState.LINKMAP = linkMap;
		set(cfgState.SPATWIN, 'UserData', spatState);

% reset spatial display
 		m_spat('INIT', get(spatState.GUI, 'UserData'));
 		figure(cfgState.SPATWIN);
		
		
%-----------------------------------------------------------------------------
%	error

	otherwise,
		error(['M_CFGS:  unrecognized action (', action, ')']);
	
end;

%=============================================================================
%	SIXDIG  - format six digit value

function tv = sixdig(v)

tv = num2str(v);
if length(tv) > 6,
	i = findstr(tv,'.');
	if isempty(i), i = length(tv); end;
	if i > 6,
		tv = '*****';
	else,
		tv = tv(1:6);
	end;
end;
