function m_help
%M_HELP  - MAVIS help support

overview = { 
'MAVIS  - Multiple Articulator Visualization tool'
''
'  v1.6 24-Oct-01  mark tiede'
''
'MAVIS is a group of integrated MATLAB functions useful for viewing'
'synchronized movement data such as that generated by point source'
'tracking methods like the magnetometer (EMMA), OPTOTRAK, or X-ray'
'microbeam systems.  It provides simultaneous display of time varying'
'trajectories and their spatial distribution at a temporal offset, which'
'can be incremented automatically for various animation effects.  MAVIS'
'also permits concurrent display of static backgrounds such as palate'
'trace or image data, and provides support for both built-in and user-'
'supplied labelling procedures.'
''
'For help on using MAVIS please see the list of "Topics" above;'
'feedback to tiede@hip.atr.co.jp'
''
};

tutorial = {
'Getting Started (A Quick Tour)'
''
'(Upper case words in the following are additional help topics, which may'
'be selected using the "Topics" menu above.)'
''
''
'--- Build a trajectory dataset'
''
'MAVIS datasets are arrays of structs, one per synchronized trajectory,'
'with at least three fields defined (name, sampling rate, and signal; see'
'DATA FORMAT for details).  Data can be of arbitrary dimension, but only'
'2 and 3 dimensional trajectories appear in the spatial plot.  A minimal'
'MAVIS dataset can be constructed using:'
''
'  >> dataSet(N) = struct( ''NAME'', ''trajName'', ...  % trajectory name'
'                          ''SRATE'', rate, ...       % sampling rate (Hz)'
'                          ''SIGNAL'', data );'
''
'for each trajectory [1:N], where size(data) == [nSamps (samples) x nDim'
'(trajectory dimensions)].'
''
''
'--- Load the dataset'
''
'Click the Data Set button in the CONTROL WINDOW to load data from a'
'stored file.  From the command line, enter'
''
'  >> mavis(dataSet)'
''
'or use one of the several additional options discussed under LOADING'
'AND SAVING.'
''
''
'--- Frame the temporal selection of interest'
''
'Once loaded, a temporal display of all signals in the dataset is shown'
'in the TRAJECTORY WINDOW.  The first signal of the dataset is used for'
'temporal FRAMING:  it is displayed in the uppermost panel of the'
'temporal display, and shows the bounds of the current selection'
'(initially spanning all the data).  To set the selection Head or Tail'
'interactively, click near the left or right edge of the selection box,'
'and drag to the desired location.  Upon release, the signal panels'
'beneath the Framing trajectory are redrawn to reflect the new selection'
'bounds.  Click and drag in the middle of the selection box to change the'
'selection offset while keeping its length constant.  Double click in the'
'framing window to restore the original full selection.  The Head and'
'Tail values may also be specified explicitly using the CONTROL WINDOW.'
''
''
'--- Set the temporal offset'
''
'A click in any temporal display panel other than the topmost used for'
'framing sets the location of the Cursor.  The contents of the SPATIAL'
'WINDOW are updated to show the relative positions of each tracked'
'trajectory at the new temporal offset.  While the mouse button is down,'
'the values of the clicked trajectory at the current Cursor location are'
'displayed in the CONTROL WINDOW.  To set a label, click using the right'
'mouse button, or with a modifier key (shift, option, control) depressed'
'simultaneously (see LABELS).'
''
''
'--- Change the spatial view'
''
'Click and drag in the SPATIAL WINDOW to change the offset of the'
'displayed data (initially centered).  Option-click to change the'
'viewpoint interactively; double-click to restore the default viewpoint. '
'The viewpoint can also be set explicitly (see SET VIEWPOINT).  By'
'default MAVIS displays spatial positions as small blobs updated to match'
'the current cursor offset.  Use SET DISPLAY OPTIONS to change the symbol'
'used, the display mode (for history or velocity tracking), and various'
'other options.  It is also possible to visually associate displayed'
'positions in various ways (see SET LINKING).'
''
''
'--- Animation'
''
'Clicking on the ">>" button of the CONTROL WINDOW causes the temporal'
'cursor and matching spatial position to be incremented automatically. '
'Cycling is controlled by the Control Window increment Step (specified in'
'msecs), and by an inter-step Delay factor.  Animation can be terminated'
'by clicking on the "0" button, or by selecting the Stop entry of the'
'Movement menu (note that exploiting the Accelator keys of this menu is'
'the easiest way to control animation).'
''
''
'--- Saving your work'
''
'The Save Dataset option in the MAVIS menu permits saving all current'
'aspects of a MAVIS session (data, configuration, labels, palate trace or'
'image data) in a single MAT file for subsequent reloading.  It is also'
'possible to selectively save data using COMMAND LINE OPTIONS.'
''
};

dataSet = {
'Data Set Format'
''
'MAVIS datasets are arrays of structs, one per synchronized trajectory. '
'Three fields are required:'
''
'  NAME    - string specifying the (unique) name of the trajectory'
'  SRATE   - trajectory data sampling rate in Hz'
'  SIGNAL  - data, arranged [nSamp (samples) x nDim (dimensions)]'
''
'MAVIS adds two additional fields if not present when the set is loaded:'
''
'  LABELS  - label data (initially empty)'
'  SCALING - data scaling information; itself a struct with fields'
'    TYPE    - either ''COMMON'' (pooled scaling) '
'                  or ''UNIQUE'' (scaled separately)'
'    RANGE   - signal scaling bounds [nDim x (min, max)]'
''
'Common scaling flags data sharing common units which should be grouped'
'together in determining display scaling (i.e., spatial movement data). '
'Unique scaling should be used for concurrently sampled data using'
'differently scaled units requiring special treatment (e.g. speech or EMG'
'data).  If the SCALING field is not present when MAVIS loads the data, by'
'default MAVIS sets monodimensional signal data to UNIQUE scaling with'
'either a [-2048 2048] RANGE (i.e., 12 bit bipolar) or [-32768 32768] RANGE'
'(16 bit bipolar), and multidimensional data to COMMON.'
''
'Labels are arrays of structs attached to a given dataset trajectory (new'
'labels are appended to the end of the current array contents).  While'
'user-defined procedures may attach additional fields, MAVIS uses the'
'following fields in its default label handlers:'
''
'  NAME    - string specifying displayed label name (may be empty)'
'  OFFSET  - label offset from time 0 in msecs'
'  NOTE    - any additional information'
'  VALUE   - trajectory value at label offset [1 x nDim]'
''
'The Value field is calculated using the Interpolation Method active at'
'the time the label was created (see CONFIGURE TRAJECTORY DISPLAY).'
''
};

ctlWin = {
'Control Window'
''
'The Control Window is used to make things happen.  The Head, Tail, and'
'Cursor fields reflect the respective current settings for these'
'parameters, and they can also be used to enter values explicitly.  The'
'Data Set button opens a dialog box for interactive selection of a'
'previously stored dataset (in MAT file format).  It is also possible to'
'enter the name of a dataset existing as a variable in the base workspace'
'in the field adjacent to the Data Set button (press Return or Enter to'
'cause it to be loaded).'
''
'The row of buttons beneath the Data Set field controls cursor placement'
'and animation.  The extreme left and right buttons reset the cursor to the'
'current selection Head and Tail respectively.  The "<<" and ">>" buttons'
'initiate automatic updating (animation) in the specified direction. '
'Single arrow buttons "<" and ">" execute a single cursor update.  The'
'center "0" button halts animation if in progress.  Each of these buttons'
'has an equivalent entry in the Movement Menu.'
''
'The animation Cursor increment is set by the Step slider or explicitly by'
'the adjacent field (value in msecs).  The Delay slider underneath can be'
'sed to interpolate a pause between Cursor updates.'
''
'The X, Y, and Z val fields show the current position of the pointer (in'
'trajectory data units) while positioned over the (active) Spatial display.'
'Clicking on a trajectory displayed in the Trajectory Window causes the'
'value of the trajectory at that temporal offset to be shown in the XYZ val'
'fields, and is updated as long as the mouse button remains pressed. '
'Clicking and dragging in the Spatial Window can be used to set the data'
'offset interactively, and the XYZ val fields show the current offset while'
'such a drag is in progress.'
''
};

framing = {
'Framing'
''
'The FRAMING panel is located at the top of the TRAJECTORY Display.  It'
'shows the time varying trajectory for one of the loaded signals (initially'
'the first trajectory of the dataset, typically audio speech data). '
'Superimposed on this is an inverted color box showing the portion of the'
'loaded dataset currently being displayed (the temporal selection).  (On'
'PCWIN platforms the selection box appears as a superimposed rectangle'
'rather than a solid patch.)'
''
'To set the selection Head or Tail interactively, click near the left or'
'right edge of the selection box and drag to the desired location.  Upon'
'release, the TRAJECTORY Display beneath the Framing trajectory is updated'
'to reflect the new selection bounds.  Click and drag in the middle of the'
'selection box to change the selection offset while keeping its length'
'constant.  A double-click in the Framing panel restores the initial full'
'selection.'
''
'By default the Trajectory Display is updated automatically after each'
'adjustment to the Framing selection.  If the refresh rate is slow, toggle'
'the Auto Update entry in the Trajectory menu.  With Auto Update'
'deselected, updating occurs only when the Update menu entry (or its'
'accelerator key) is explicitly chosen.'
''
'By default MAVIS uses the first trajectory of a loaded dataset as its'
'Framing trajectory.  Use the CONFIGURE TRAJECTORY DISPLAY dialog to select'
'an alternative.'
''
};

trajWin = {
'Trajectory Window'
''
'The Trajectory window shows a temporal display of user-selected signals'
'for the current selection beneath the topmost FRAMING panel.  Initially'
'all loaded trajectories are displayed, over the longest range for which'
'all signals have data.  Control over which trajectories are to be'
'displayed and their relative ordering is exercised through the CONFIGURE'
'TRAJECTORY Display dialog.  Only trajectories displayed in the Trajectory'
'Window are concurrently plotted in the SPATIAL Display.'
''
'Multiple trajectory dimensions are superimposed within the same panel,'
'with each additional dimension plotted in a diminished intensity variant'
'of the base color.  Multidimensional trajectories are plotted in colors'
'matched to those used in the SPATIAL Display.'
''
'Trajectories are plotted within equal height panels.  Unique-scaled data'
'(e.g. speech, EMG) are plotted using the associated SCALING.RANGE (see'
'DATASET FORMAT).  Pooled trajectory data are plotted centered within each'
'panel scaled by the largest range (spread) across all Common-scaled data'
'currently plotted.  This automatically determined spread can be overridden'
'within the Configuration Dialog (specify Fixed scaling).'
''
'A click in any temporal display panel resets the location of the Cursor,'
'and updates the contents of the SPATIAL WINDOW to show the relative'
'positions of each displayed trajectory at the new temporal offset.  While'
'the mouse button is down, the values of the clicked trajectory at the'
'current Cursor location are displayed in the CONTROL WINDOW.  To set a'
'label, click using the right mouse button, or with a modifier key (shift,'
'option, control) depressed simultaneously (see LABELS).'
''
'The Trajectory Window is also affected by Trajectory Menu items:'
''
'Backing Store (enabled by default) uses additional memory to retain a copy'
'of plotted data for fast restoration when an obscured portion of the'
'window is once again brought forward.  Deselecting this option will result'
'in faster plotting (and less hidden memory usage); however, the window'
'will redraw more slowly after being obscured (by configuration dialogs,'
'for example).'
''
'Plot Samples is useful when the temporal selection is such that there are'
'more screen pixels than trajectory samples; select this option to see the'
'exact sample locations.'
''
'Show Midlines (enabled by default) plots a dotted reference line through'
'the center of each panel.'
''
'Toggle Background toggles the figure basis between black and white'
'backgrounds.'
''
'Clone Window duplicates the Trajectory Display in a new figure accessible'
'to the base MATLAB environment (for copying, printing, et cetera).'
''
'Auto Update (enabled by default) controls whether the Trajectory Window is'
'updated immediately when the FRAMING selection changes, or deferred to an'
'explicit Update.'
''
'Full Selection restores the initial full temporal selection (as a shortcut'
'with the same effect, double-click within the Framing Panel).'
''
'Yack Selection produces scaled sound output (using soundsc) of the current'
'selection on supported platforms, if the framing trajectory is'
'monodimensional and has a sampling rate >= 500Hz.'
''};

trajCfg = {
'Configure Trajectory Display'
''
'Use this dialog to control the appearance of the Trajectory Window.'
'Initially all loaded dataset trajectories are displayed; the Loaded and'
'Displayed lists permit control of which trajectories should appear in the'
'Trajectory (and Spatial) displays, and their relative ordering.  To move'
'trajectories from one list to the other first select the names to be'
'transferred (control-click for multiple selection), then click the button'
'between the two lists.'
''
'By default MAVIS uses the first trajectory of the dataset for FRAMING.  To'
'change the framing trajectory, double-click on a trajectory name in one of'
'the two list boxes.'
''
'Because MAVIS permits arbitrary time-based positioning of the temporal'
'offset Cursor, three methods are supported for inter-sample trajectory'
'value Interpolation:'
''
'  Nearest Neighbor - closest sample value (fastest)'
'  Linear           - linear interpolation between samples (default)'
'  Cubic            - cubic interpolation (4 sample neighborhood)'
''
'By default trajectories are plotted centered within Trajectory Display'
'panels scaled by the largest range (spread) across all Common-scaled'
'trajectory data (see DATASET FORMAT) currently plotted.  This'
'automatically determined spread can be overridden by enabling the Fixed'
'radio button option, and by specifying the scaling Spread explicitly.  Use'
'the Apply button to view the effects of Fixed scaling without exiting the'
'configuration.'
''
'It is possible to display trajectory dimensions selectively using the'
'Show checkboxes.  Use the Other checkbox to control display of higher'
'(i.e. > 3) or monodimensional data.'
''
};

spatWin = {
'Spatial Window'
''
'The Spatial Display shows the distribution of data point source locations'
'at the current Cursor temporal offset, optionally overlaid onto image or'
'palate trace reference data.  Control of the appearance and scaling of'
'data points is exercised through the four Spatial configuration dialogs'
'(SET VIEWPOINT, DISPLAY OPTIONS, LINKING, SCALING) and the other Spatial'
'Menu entries (see below).  Only Common-scaled data trajectories (see'
'DATASET FORMAT) displayed in the TRAJECTORY Window are concurrently'
'plotted in the Spatial Window.'
''
'By default data are plotted using the minimum and maximum of all displayed'
'trajectories to scale locations to the current window size.  Identical'
'scaling is used for each trajectory dimension.  This scaling and the'
'offset of the data within the window may be overridden by specifying Fixed'
'scaling in the Scaling configuration dialog.  The offset of the data'
'(relative to the center of the min/max range) may also be changed'
'interactively, by clicking and dragging within the Spatial display.'
''
'Initially MAVIS displays data using a default view appropriate to the'
'number of dimensions.  The view may be changed interactively by'
'option-clicking and dragging within the Spatial display, or explicitly'
'using the Set Viewpoint dialog.  A double-click within the Spatial display'
'restores the original default view.'
''
'In addition to the configuration dialogs the following Spatial Menu items'
'can be used to control the Spatial Display:'
''
'Fast Rendering (enabled by default) bypasses hidden surface elimination'
'and object intersection handling, resulting in faster plotting; however it'
'may give unsatisfactory results in the display of 3-dimensional data and'
'may be toggled off using this menu item.'
''
'Toggle Background toggles the figure basis between black and white'
'backgrounds.'
''
'Clone Window duplicates the Spatial Display in a new figure accessible'
'to the base MATLAB environment (for copying, printing, et cetera).'
''
'Hue Plot Selection (thanks Phil Hoole) generates a lissajous plot of each'
'trajectory over the range of the current temporal selection.  The color of'
'each traced path is varied continuously through the active colormap, such'
'that the beginning of the path (selection Head position) is rendered in'
'the first colormap color, and the end of the path (selection Tail) is'
'rendered in the last.'
''
'Reset View restores the original default view and resets Auto scaling (as'
'a shortcut with the same effect, double-click within the Spatial Display).'
''
};

cfgView = {
'Set Viewpoint'
''
'Use this dialog to explicitly set the viewpoint onto displayed Spatial'
'data by controlling Azimuth and Elevation (values in degrees).  The'
'viewpoint may also be set interactively (using rotate3d) by option-'
'clicking and dragging within the Spatial Display.'
''
'The display order of an axis may be inverted independently of the view'
'by selecting its associated checkbox.'
''
'Use the Set Default button to specify the currently displayed view as'
'the default (restored by Reset View, or double-clicking on the Spatial'
'Display).'
''
};

cfgOpt = {
'Set Display Options'
''
'Use this dialog to control the appearance of the Spatial Display. '
'Currently four display modes are supported:'
''
'  Blobs (default) - locations are plotted using the currently selected'
'                      symbol and size'
'  No Erasure      - same as above, except that previous locations are not'
'                      erased when the temporal offset changes'
'  Track Velocity  - plotted marker size is correlated with trajectory '
'                      velocity at that offset'
'  History Ghosts  - a trail of ten previous locations is plotted in '
'                      diminishing intensity from the base color'
''
'The displayed symbol can be selected from the list of pulldown menu'
'choices, and the base size for its display can be entered either by slider'
'or in the adjacent field.'
''
'By default a reference grid is superimposed on the Spatial Display; use'
'the Show Grid checkbox to control its display.'
''
'Palate trace (or other fixed reference data) is assumed to be a [nSamps'
'(samples) x nDims (dimensions)] array of data in the same units as the'
'displayed trajectories.  It may be entered from a MAT file (see LOADING'
'AND SAVING) or directly if it exists as a variable in the base workspace'
'by entering the variable name in the field adjacent to the Palate Trace'
'checkbox (the checkbox itself controls whether loaded data is displayed).'
''
'Image data may be loaded and displayed in similar fashion using the Image'
'variable field and display checkbox.  The pix/mm field is used to'
'calibrate the relationship between the image and displayed spatial data'
'units.'
''
'All changes made in this dialog are reflected immediately in the Spatial'
'Display (press Return or Enter to activate an edited text field).  Use the'
'Cancel Button to exit the dialog and revert to the inital entry state.'
''};

cfgLink = {
'Set Linking'
''
'To facilitate visualization of structures mapped by related data points'
'(e.g. tongue surface, lip contour), MAVIS supports point "linking," which'
'causes lines to be plotted between trajectory positions specified using'
'this dialog.  The order used to join positions is the order in which they'
'appear in the Linked list.'
''
'To move trajectories between the Displayed and Linked lists, first select'
'the names to be transferred (control-click for multiple selection), then'
'click the button between the two lists.'
''
'Four types of linking are supported:'
''
'  Off (default)  - the link order is preserved, but no lines are drawn'
'  Lines (open)   - straight lines are drawn between points'
'  Lines (closed) - an additional line is drawn between the first and last'
'  Natural Spline - interpolated by cubic spline (natural end conditions)'
''
};

cfgScale = {
'Set Scaling'
''
'By default data are plotted using the minimum and maximum of all displayed'
'trajectories to scale locations to the current window size.  Identical'
'scaling is used for each trajectory dimension.  This Automatic scaling and'
'the offset of the data within the window may be overridden using this'
'dialog by specifying Fixed scaling and explicit spread and offset values. '
'The offset of the data (relative to the center of the min/max range) may'
'also be changed interactively, by clicking and dragging within the Spatial'
'display.'
''
};

loadSave = {
'Loading and Saving'
''
'MAVIS can load datasets (see DATASET FORMAT) in three different ways.  If'
'the dataset exists as a variable in the base workspace, then it may be'
'loaded by entering the name of the variable in the field adjacent to the'
'Data Set button of the CONTROL WINDOW (it may also be loaded from the'
'command line -- see COMMAND LINE OPTIONS).  If the dataset exists as a'
'variable with the same name as a stored MAT file (which is how MAVIS saves'
'datasets), then it may be loaded by interactive dialog opened by selecting'
'the Open Dataset menu option, or by clicking the Control Window Data Set'
'button.  Finally, by selecting the appropriate menu option datasets may'
'also be imported:  from MAT files (containing more than one potential'
'dataset variable), Haskins PCM, or U. Wisconsin microbeam format files.'
''
'Datasets may be saved to MAT files for subsequent reloading by selecting'
'the Save Dataset menu option.  Besides the dataset itself MAVIS saves the'
'current configuration and any reference (palate trace or image) data as'
'well, permitting recovery of the identical state when saved.'
''
'Since it may not be efficient to save multiple copies of large datasets,'
'MAVIS also supports loading and saving of configuration data only.  The'
'MAVIS configuration is stored as a structure called cfg written to a'
'user-specified MAT file.  Configurations may be loaded from any MAT file'
'containing the cfg structure variable.'
''
'Palate trace (or other fixed reference data) is assumed to be a [nSamps'
'(samples) x nDims (dimensions)] array of data in the same units as the'
'displayed trajectories.  It may be loaded from any MAT file containing the'
'data as a variable named pal by selecting the Load Palate Trace menu'
'option.'
''
'Images are assumed to be a [rows x cols] array of monochromatic image data'
'in either double or uint8 format (see MATLAB documentation for images). '
'It may be loaded from a MAT file containing the data as a variable named'
'img, or imported from an (imread) supported image format file by selecting'
'the appropriate menu entry.'
''
'MAVIS also supports loading and exporting data as variables from and to'
'the base workspace; see COMMAND LINE OPTIONS.'
''
};

cmdOpt = {
'Command Line Options...'
''
'... can be used to initialize MAVIS, load data, and return data in various'
'forms to the base workspace.'
''
'By itself'
''
'  >> mavis'
''
'initializes the GUI if necessary, or if already active brings the three'
'MAVIS windows foremost.  To load a dataset defined as a variable in the'
'workspace, use'
''
'  >> mavis(dataSetVar)'
''
'which will also initialize the GUI if need be.  Data can also be loaded as'
'a series of name:value pairs, as in'
''
'  >> mavis(''Name1'', ''Value1'', ..., ''NameN'', ''ValueN'')'
''
'where NAME can be one of'
'    DATA    - dataset'
'    CONFIG  - configuration data'
'    IMAGE   - image data'
'    PALATE  - palate trace data'
''
'The currently loaded dataset (including scaling info and labels) may'
'exported to the base workspace using'
''
'  >> dataSet = mavis(''GETDATA'')'
''
'The current temporal selection can be exported using'
''
'  >> dataSel = mavis(''GETSEL'')'
''
'With this option, only those trajectories currently displayed are'
'exported.  Label offsets are adjusted for the exported selection Head.'
''
'The current configuration may be exported using'
''
'  >> cfg = mavis(''GETCFG'')'
''
'Labels may be exported using'
''
'  >> lbl = mavis(''GETLAB'')'
''
'which returns an array of structs, one per dataset trajectory with defined'
'labels, containing the name of the trajectory and a copy of the labels'
'associated with it.'
''
'One additional option is supported:  in case some lurking glitch prevents'
'closing MAVIS normally, entering'
''
'  >> mavis ABORT'
''
'should successfully slay the monster.'
''
};

labels = {
'Labels and Labelling'
''
'In the default support provided by MAVIS labels are (optionally named)'
'markers attached to trajectories at some temporal offset.  Label display'
'may be toggled using the Show Labels menu option.  To set a label, click'
'using the right mouse button, or with a modifier key (shift, option,'
'control) depressed.  When the mouse button is released, a label is created'
'at the current cursor offset.'
''
'Initially labels are "annotated"; that is, when created a dialog appears'
'permitting the user to specify the label name and auxillary information,'
'adjust the offset, and set the trajectories to which the new label should'
'be applied.  By deselecting the Annotate option in the Configure Labelling'
'dialog, (unnamed) labels are created immediately, and applied to either'
'all trajectories or the clicked trajectory as specified in the'
'Configuration dialog.  Existing labels may be edited or selectively'
'deleted by means of the Edit Labels dialog.  Choosing the Clear All Labels'
'menu option deletes all labels from the dataset.'
''
'Labels are arrays of structs attached to a given dataset trajectory (new'
'labels are appended to the end of the current array contents).  While'
'user-defined procedures may attach additional fields, MAVIS uses the'
'following fields in its default label handlers:'
''
'  NAME    - string specifying displayed label name (may be empty)'
'  OFFSET  - label offset from time 0 in msecs'
'  NOTE    - any additional information'
'  VALUE   - trajectory value at label offset [1 x nDim (dimensions)]'
''
'The Value field is calculated using the Interpolation Method active at the'
'time the label was created (see CONFIGURE TRAJECTORY DISPLAY).'
''
'MAVIS also supports user-defined label handlers, which can be used to'
'extend or automate trajectory analysis in various ways.  A User Label'
'Procedure may be selected interactively using the Set User Proc button'
'of the Configure Labelling dialog, or its name entered directly into the'
'adjacent field (user procedures must be visible on the current MATLAB path'
'to be accessible to MAVIS).  Clear the field contents to restore default'
'labelling behavior.'
''
'User labelling procedures are called under three conditions:  when first'
'selected (to permit any necessary configuration), when a modified mouse down'
'event occurs within a Trajectory Display panel, and whenever labels need'
'to be plotted.  Several user labelling procedures are supplied with MAVIS;'
'enter ''dir ml*'' at the command line within the MAVIS directory to see'
'a list, and enter ''help ml_<name>'' for a functional description.'
''
};

%	assemble the window

s = {
'Overview' overview ;
'Getting Started' tutorial ;
'Dataset Format' dataSet ;
'Control Window' ctlWin ;
'Framing', framing ;
'Trajectory Window' trajWin ;
'  Configure Trajectory Display' trajCfg ;
'Spatial Window' spatWin ;
'  Set Viewpoint' cfgView ;
'  Set Display Options' cfgOpt ;
'  Set Linking' cfgLink ;
'  Set Scaling' cfgScale ;
'Loading and Saving' loadSave ;
'Command Line Options' cmdOpt ;
'Labels and Labelling' labels
	};

helpwin(s, 'Overview', 'MAVIS Help');
