function m_traj(action, aux, aux2)
%M_TRAJ  - MAVIS trajectory window support

%	branch by action...

switch action,

%-----------------------------------------------------------------------------
%	AUTO:  toggle auto update status

	case 'AUTO',
		[state, trajState] = FindState;
		trajState.AUTOUPDATE = umtoggle(gcbo);
		set(state.TRAJWIN, 'UserData', trajState);
		if trajState.AUTOUPDATE, s = 'on'; else, s = 'off'; end;
		set(state.MENUS(:,1), 'Checked', s);
		if ~trajState.INITIALIZED, return; end;	
		if trajState.AUTOUPDATE, Redraw(trajState); end;
		

%-----------------------------------------------------------------------------
%	BSTORE:  toggle backing store status

	case 'BSTORE',
		state = FindState;
		bs = umtoggle(gcbo);
		if bs,  s = 'on'; else, s = 'off'; end;
		set(state.TRAJWIN, 'BackingStore', s);
		set(state.MENUS(:,2), 'Checked', s);
		

%-----------------------------------------------------------------------------
%	CLOSE:  trap close window requests

	case 'CLOSE',
		m_gui('CLOSE');
					
	
%-----------------------------------------------------------------------------
%	CURSOR:  show/hide trajectory window cursor

	case 'CURSOR',
		h = findobj('Tag', 'TRAJ');
		trajState = get(h, 'UserData');	
		switch aux,
			case 'SHOW',
				set(gcbf, 'Visible', 'off');
				drawnow;
				set(trajState.CURSORL, 'Visible', 'on');
			case 'HIDE',
				set(trajState.CURSORL, 'Visible', 'off');
		end;
		

%-----------------------------------------------------------------------------
%	DOWN:  mouse down

	case 'DOWN',
		global SLOP M_NONE M_HEAD M_TAIL M_CURS M_LABEL msecsToSamps fixstr;
		trajState = get(gcbf, 'UserData');
		if ~trajState.INITIALIZED, return; end;
		state = get(trajState.GUI, 'UserData');
	
%	click in analysis body is cursor update
		curPt = get(trajState.CURSORH, 'CurrentPoint');
		x = curPt(1,1);
		y = curPt(1,2);
		xLim = get(trajState.CURSORH, 'XLim');			
		yLim = get(trajState.CURSORH, 'YLim');
		if (x > xLim(1)) & (x < xLim(2)) & (y > yLim(1)) & (y < yLim(2)), 
		
			set(trajState.CURSORL, 'XData', [x x]);			% set cursor position
			state.CURSOR = x;
			set(trajState.GUI, 'UserData', state);
			set(state.CURSF, 'String', fixstr(x));
			m_spat('UPDATE', state);
			
			t = 0;
			p = 2;	
			while p <= length(trajState.PANELS),
				curPt = get(trajState.PANELS(p), 'CurrentPoint');
				y = curPt(1,2);
				yLim = get(trajState.PANELS(p), 'YLim');
				if (y >= yLim(1)) & (y <= yLim(2)),
					t = trajState.DISPMAP(p-1);				% index into state.DATA of clicked trajectory
					p = length(trajState.PANELS) + 1;
				end;
				p = p + 1;				
			end;
			trajState.TRACK = t;
			
			switch get(gcbf, 'SelectionType'),
				case 'normal',	% (left button/unmodified click) fall thru
					mode = M_CURS;
				case 'open', 	% (double-click) flare corresponding spatial blob
					if strcmp(state.DATA(t).SCALING.TYPE, 'COMMON'),
						spatState = get(state.SPATWIN, 'UserData');
						i = find(spatState.PLOTMAP == t);
						h = spatState.BLOBS(i);
						s = get(h, 'MarkerSize');
						set(h, 'MarkerSize', s*2);
 						tic;
 						while toc < .25, end;	% delay
						set(h, 'MarkerSize', s);
					end;
					return;
				otherwise,		% (right button/modified click)
					if isempty(state.LABEL.PROC), 
						mode = M_LABEL;								% default labelling proc
					elseif t > 0,
						set(gcbf, 'UserData', trajState);			% for TRACK
						feval(state.LABEL.PROC, 'DOWN', state, t); 	% user proc
						return;
					end;
					
			end;

			h = [state.XVALF state.YVALF state.ZVALF];
			v = m_gui('GETVAL', state, t, x);
			for c = 1 : length(v),		% update displayed X, Y, Z values
				sv = num2str(v(c));
				if length(sv) > 6, sv = sv(1:6); end;
				set(h(c), 'String', sv);
			end;
			set(h(c+1:3), 'String', '');
			trajState.MODE = mode;
			set(gcbf, 'UserData', trajState, ...
				'WindowButtonMotionFcn', 'm_traj MOVE;', ...
				'WindowButtonUpFcn', 'm_traj UP;');
			return;
		end;

%	click in framing panel is bounds adjust
		curPt = get(trajState.PANELS(1), 'CurrentPoint');
		x = curPt(1,1);
		y = curPt(1,2);
		
% 	ignore if out of plotting bounds		
		xLim = get(trajState.PANELS(1), 'XLim');			
		yLim = get(trajState.PANELS(1), 'YLim');
		if (x < xLim(1)) | (x > xLim(2)) | (y < yLim(1)) | (y > yLim(2)), return; end;

% 	double click sets full selection
		if strcmp(get(gcbf, 'SelectionType'), 'open'),
			m_traj('FULL');
			return;
		end;
		
% 	determine mode based on click loc relative to selection edges		
		pos = get(gcbf, 'Position');		% cvt to pixels
		pos = [x msecsToSamps(state.HEAD, trajState.FSRATE) msecsToSamps(state.TAIL, trajState.FSRATE)] / (xLim(2) / pos(3));
		if (pos(1)>pos(2)-SLOP) & (pos(1)<pos(2)+SLOP),
			mode = M_HEAD;					% move head
		elseif (pos(1)>pos(3)-SLOP) & (pos(1)<pos(3)+SLOP),
			mode = M_TAIL;					% move tail
		elseif (pos(1)>pos(2)) & (pos(1)<pos(3)),
			mode = -round(x);				% move selection (save starting point as negated mode)
		else,
			mode = M_NONE;					% ignore click
		end;
		trajState.MODE = mode;
		set(gcbf, 'UserData', trajState);
		if mode ~= M_NONE,
			set(gcbf, 'WindowButtonMotionFcn', 'm_traj MOVE;', ...
				'WindowButtonUpFcn', 'm_traj UP;');
		end;


%-----------------------------------------------------------------------------
%	DRAWCURS:  update cursor (aux holds state)

	case 'DRAWCURS',
		state = aux;
		trajState = get(state.TRAJWIN, 'UserData');
		set(trajState.CURSORL, 'XData', [state.CURSOR state.CURSOR]);
					
	
%-----------------------------------------------------------------------------
%	FULL:  set current selection to full range

	case 'FULL',
		global msecsToSamps fixstr;
		[state, trajState] = FindState;
		if ~trajState.INITIALIZED, return; end;
		state.HEAD = 0;
		state.TAIL = state.MAXTAIL;
		fnSamps = msecsToSamps(state.MAXTAIL, trajState.FSRATE);
		set(trajState.BOUNDS, 'XData', [1 1 fnSamps fnSamps]);
		set(state.CURSF, 'String', '0');
		set(state.HEADF, 'String', '0');
		set(state.TAILF, 'String', fixstr(state.MAXTAIL));
		set(trajState.GUI, 'UserData', state);
		Redraw(trajState);


%-----------------------------------------------------------------------------
%	INITialize
% 
%	aux holds (gui) state
%	if aux2 is nonzero or nonempty current head, tail, cursor positions are retained

	case 'INIT',
		global SLOP M_NONE M_HEAD M_TAIL M_CURS msecsToSamps sampsToMsecs fixstr;
		squish = 0.2;			% squish factor (make data fit within panels)
		state = aux;
		trajState = get(state.TRAJWIN, 'UserData');
		if nargin < 3 | ~trajState.INITIALIZED, reInit = 0; else, reInit = aux2; end;

		set(state.TRAJWIN, 'HandleVisibility', 'on');
		figure(state.TRAJWIN);
		if trajState.INITIALIZED, clf; end;		% clear old data
		if trajState.MIDLINES, ml = 'on'; else, ml = 'off'; end;	% midline visibility

% init selection:  map tail to length of shortest channel, compute min head:tail separation
		if ~all(ismember(trajState.DISPMAP, [1:length(state.DATA)])),
			trajState.DISPMAP = [1 : length(state.DATA)];	% avoid index mismatch
		end;
		fData = state.DATA(trajState.FRAME);		% framing data
		plotMap = trajState.DISPMAP;				% indices of plotted trajectories
		if reInit,									% remember state on re-initialization
			saveState = struct('HEAD', state.HEAD, 'TAIL', state.TAIL, 'CURSOR', state.CURSOR);
		end;
		state.HEAD = 0;							
		state.CURSOR = 0;
		state.TAIL = sampsToMsecs(size(fData.SIGNAL,1), fData.SRATE);
		minSR = fData.SRATE;
		for t = plotMap,
			tail = sampsToMsecs(size(state.DATA(t).SIGNAL,1), state.DATA(t).SRATE);
			if tail < state.TAIL, state.TAIL = tail; end;
			if state.DATA(t).SRATE < minSR, minSR = state.DATA(t).SRATE; end;
		end;
		state.MAXTAIL = state.TAIL;
		state.MINSTEP = ceil(1000/minSR);

% panel layout	
		nPanels = length(plotMap) + 1;			% number of plotted panels
		ph = zeros(1, nPanels);					% panel axis handles
		for p = 1 : nPanels,
			ph(p) = subplot(nPanels, 1, p);
		end;
		
% compute panel vertical bounds
		position = get(ph(1),'position');
		d = position(2) - .007;
		dd = (d - .04)/(nPanels-1);
		d = [d : -dd : .04];

% scale framing data
		[nSamps, nComps] = size(fData.SIGNAL);
		nSamps = msecsToSamps(state.MAXTAIL, fData.SRATE);
		mins = fData.SCALING.RANGE(:,1)';
		spreads = (fData.SCALING.RANGE(:,2)' - mins) / 2;
		spread = max(spreads);
		spread = spread + spread * squish;			% squish
		fData.SIGNAL = fData.SIGNAL(1:nSamps,:) - repmat(mins+spreads,nSamps,1);

% plot framing data
		if any(get(state.TRAJWIN, 'Color') < .5), 
			isWhiteBG = 0;
			frameColor = [1 1 1]; 
 			boxColor = [.2 .2 .2];
		else, 
			isWhiteBG = 1;
			frameColor = [0 0 0]; 
			boxColor = [.8 .8 .8];
		end;
		subplot(ph(1));
		hold on;
		position = get(gca,'position');
		position(1) = .05;
		position(3) = .925;
		position(4) = min([(.95 - d(1)) (d(1) - d(2))]);
		set(ph(1), 'xlim', [1 nSamps], ...
			'ylim', [-spread spread], ...
			'xtick', [], ...
			'ytick', [], ...
			'position', position, ...
			'Box', 'on');
		plot([1:nSamps], fData.SIGNAL(:,1), 'Color', frameColor);
		color = [1 1 1];
		c = 1;
		while (c < nComps),				% handle multiple-component framing data
			c = c + 1;
			color = color .* .7;
			plot([1:nSamps], fData.SIGNAL(:,c), ...
				'color', color);
		end;
		trajLabs(1) = text(1, spread, ...
			[' ', fData.NAME], ...
			'VerticalAlignment', 'top', ...
			'fontname', 'geneva', ...
			'fontsize', 9, ...
			'color', frameColor);
		hold off;
		fsRate = fData.SRATE;
		clear fData;					% free memory
		
% selection patch		
		subplot(ph(1));
		hold on;
		if strcmp(computer, 'PCWIN'),
			bounds = patch([1 1 nSamps nSamps], [-spread spread spread -spread]*.95, boxColor, ...
				'EdgeColor', frameColor, ...
				'FaceColor', 'none', ...
				'EraseMode', 'xor');
		else,
			bounds = patch([1 1 nSamps nSamps], [-spread spread spread -spread], boxColor, ...
				'EdgeColor', boxColor, ...
				'EraseMode', 'xor');
		end;
		hold off;
		
% scale trajectory data
		sData = state.DATA(plotMap);			% clone displayed input data for subsquent scaling
		nTraj = length(sData);					% number of displayed trajectories
		if trajState.AUTOSCALE,					% autoscaling:  compute scaling pooled across all trajectories
			spread = 0;
			for t = 1 : nTraj,
				if strcmp(sData(t).SCALING.TYPE, 'COMMON'),
					nSamps = msecsToSamps(state.MAXTAIL, sData(t).SRATE);
					mins = min(sData(t).SIGNAL(1:nSamps,:));
					maxs = max(sData(t).SIGNAL(1:nSamps,:));
					spread = max([spread, max(max((maxs-mins)/2))]);
				end;
			end;
			spread = spread + spread * squish;	% squish
		else,
			spread = trajState.SPREAD;			% fixed scaling
		end;
		nc = 0;		% number of colors
		for t = 1 : nTraj,
			if strcmp(sData(t).SCALING.TYPE, 'COMMON'),
				nSamps = msecsToSamps(state.MAXTAIL, sData(t).SRATE);
				mins = min(sData(t).SIGNAL(1:nSamps,:));
				maxs = max(sData(t).SIGNAL(1:nSamps,:));
				sData(t).SIGNAL = sData(t).SIGNAL - repmat(mins+(maxs-mins)/2,size(sData(t).SIGNAL,1),1);
				sData(t).SCALING.RANGE = [-spread spread];
				nc = nc + 1;
			else,
				sData(t).SCALING.RANGE = [min(sData(t).SCALING.RANGE(:,1)) max(sData(t).SCALING.RANGE(:,2))];
				sData(t).SCALING.RANGE = sData(t).SCALING.RANGE + sData(t).SCALING.RANGE*squish;
			end;
		end;		

%	plot trajectory data
		map = get(state.TRAJWIN, 'colormap');
		if get(0,'ScreenDepth') < 16, numCols = 16; else, numCols = 64; end;
		if nc, md = numCols / nc; end;
		if trajState.PLOTSAMPS, ps = '-o'; else, ps = '-'; end;
		ci = 1;		% color index
		for t = 1 : nTraj,
			subplot(ph(t+1));		% panel axes offset by one (framing panel)
			[nSamps, nComps] = size(sData(t).SIGNAL);
			nSamps = msecsToSamps(state.MAXTAIL, sData(t).SRATE);
			set(ph(t+1), 'xlim', [1 nSamps], ...
				'ylim', sData(t).SCALING.RANGE, ...
				'ytick', [], ...
				'xtick', [], ...
				'position', [.05 d(t+1) .925 d(t)-d(t+1)+.005], ...
				'Box', 'on');
 			if strcmp(sData(t).SCALING.TYPE, 'COMMON'),
				color = map(floor((ci-1)*md)+1,:);
				ci = ci + 1;
 			else,
 				color = frameColor;
 			end;
			hold on;
			plot([1 nSamps], [1 1]*mean(sData(t).SCALING.RANGE), ':', ...
				'Tag', 'midline', ...
				'Visible', ml, ...
				'Color', [.5 .5 .5]);
			tc = color;
			for c = 1 : nComps,
				if c>=4 | nComps==1, vs = trajState.SHOWTRAJ(4); else, vs = trajState.SHOWTRAJ(c); end;
				cc = color;
				if vs, vs = 'on'; color = color * .5; else, vs = 'off'; end;
				plot([1:nSamps], sData(t).SIGNAL(1:nSamps,c), ps, ...
					'Tag', 'data', ...
					'Visible', vs, ...
					'Color', cc);
			end;
			if isWhiteBG, tc = color; end;
			trajLabs(t+1) = text(1, sData(t).SCALING.RANGE(2), ...
				[' ' sData(t).NAME], ...
				'VerticalAlignment', 'top', ...
				'fontname', 'geneva', ...
				'fontsize', 9, ...
				'Color', tc);
			if state.LABEL.DISPLAY,
				for n = 1 : length(sData(t).LABELS),	% plot any labels
					x = sData(t).LABELS(n).OFFSET * sData(t).SRATE/1000 + 1;
					if isempty(state.LABEL.PROC),	% default plotting
						m_label('PLOT', x, sData(t).SCALING.RANGE, sData(t).LABELS(n));
					else,							% user proc
						feval(state.LABEL.PROC, 'PLOT', x, sData(t).SCALING.RANGE, sData(t).LABELS(n));
					end;
				end;
			end;
			hold off;
		end;
		
% cursor:  XLim is msec-based in state.HEAD : TAIL range
		hold on;
		pos = get(ph(2), 'position');
		cursorH = axes('position', [pos(1) d(end) pos(3) pos(2)+pos(4)-d(end)], ...
					'xlim', [state.HEAD state.TAIL], 'ylim', [0 1], ...
					'ytick', [], 'color', 'none');
		cursorL = line([0 0], [0 1], 'color', frameColor, 'EraseMode', 'xor');
		xlabel('msecs');
		hold off;
		
% update trajectory window internal state
		trajState.MODE = M_NONE;			% movement mode
		trajState.FSRATE = fsRate;			% framing data sampling rate
		trajState.PANELS = ph;				% panel axes
		trajState.TRAJLABS = trajLabs;		% trajectory name handles
		trajState.CURSORH = cursorH;		% cursor axis
		trajState.CURSORL = cursorL;		% cursor line
		trajState.BOUNDS = bounds;			% selection patch handle
		trajState.SPREAD = spread;			% spread
		trajState.TRACK = [];				% current trajectory for value tracking
		trajState.INITIALIZED = 1;			% got data
		
		if reInit,
			state.HEAD = saveState.HEAD;
			state.TAIL = saveState.TAIL;
			state.CURSOR = saveState.CURSOR;
		else,
			set(state.CURSF, 'String', '0');
			set(state.HEADF, 'String', '0');
			set(state.TAILF, 'String', fixstr(state.MAXTAIL));
		end;
		set(state.XVALF, 'String', '');
		set(state.YVALF, 'String', '');
		set(state.ZVALF, 'String', '');
		
		set(state.TRAJWIN, 'UserData', trajState, 'HandleVisibility', 'callback');
		set(trajState.GUI, 'UserData', state);
		
		if reInit, m_traj('UPDATE', trajState); end;
		
		
%-----------------------------------------------------------------------------
%	MIDLINES:  toggle midlines plotting status

	case 'MIDLINES',
		[state, trajState] = FindState;
		trajState.MIDLINES = umtoggle(gcbo);
		set(state.TRAJWIN, 'UserData', trajState);
		if trajState.MIDLINES, s = 'on'; else, s = 'off'; end;
		set(state.MENUS(:,4), 'Checked', s);
		if ~trajState.INITIALIZED, return; end;	
		for p = 2 : length(trajState.PANELS),
			lines = findobj(trajState.PANELS(p), 'Tag', 'midline');
			set(lines, 'visible', s);
		end;
		

%-----------------------------------------------------------------------------
%	MOVE:  change selection based on current mode

	case 'MOVE',
		global M_NONE M_HEAD M_TAIL M_CURS msecsToSamps sampsToMsecs fixstr;
		trajState = get(gcbf, 'UserData');
		state = get(trajState.GUI, 'UserData');
	
%	handle cursor movement
		if trajState.MODE >= M_CURS,
			curPt = get(trajState.CURSORH, 'CurrentPoint');
			x = curPt(1,1);
			y = curPt(1,2);
% 	ignore if out of plotting bounds		
			xLim = get(trajState.CURSORH, 'XLim');			
			yLim = get(trajState.CURSORH, 'YLim');
			if (x < xLim(1)) | (x > xLim(2)) | (y < yLim(1)) | (y > yLim(2)), return; end;
			xd = get(trajState.CURSORL, 'XData');
			if x ~= xd(1),
				set(trajState.CURSORL, 'XData', [x x]);
				state.CURSOR = x;
				set(state.CURSF, 'String', fixstr(x));
				set(trajState.GUI, 'UserData', state);
				m_spat('UPDATE', state);
				h = [state.XVALF state.YVALF state.ZVALF];
				v = m_gui('GETVAL', state, trajState.TRACK, x);
				for c = 1 : length(v),
					sv = num2str(v(c));
					if length(sv) > 6, sv = sv(1:6); end;
					set(h(c), 'String', sv);
				end;
			end;
			return;
		end;

% 	handle selection change
		curPt = get(trajState.PANELS(1), 'CurrentPoint');
		x = curPt(1,1);
		y = curPt(1,2);
		
% 	ignore if out of plotting bounds		
		xLim = get(trajState.PANELS(1), 'XLim');			
		yLim = get(trajState.PANELS(1), 'YLim');
		if (x < xLim(1)) | (x > xLim(2)) | (y < yLim(1)) | (y > yLim(2)), return; end;
		
		ns = xLim(2);
		x = round(x);
		if x<1, x=1; elseif x>ns; x=ns; end;
		head = msecsToSamps(state.HEAD, trajState.FSRATE);
		tail = msecsToSamps(state.TAIL, trajState.FSRATE);
		mode = trajState.MODE;
		pos = get(gcbf, 'Position');
		sampPerPix = xLim(2) / pos(3);
		p = [x head tail] / sampPerPix;		% cvt to pixels
			
% 	limit min selection range...
		minStep = msecsToSamps(state.MINSTEP, trajState.FSRATE);
		if mode == M_HEAD,		% ...to one pixel or sample fore of tail
			if (x > head) & (p(1) > p(3)-1), 
				x = floor((p(3)-1) * sampPerPix);
				if x < 1, x = 1; end;
				if x >= tail-minStep, x = tail-minStep; end;
			end;
			head = x;
			
		elseif mode == M_TAIL,	% ...to one pixel or sample aft of head
			if (x < tail) & (p(1) < p(2)+1),
				x = ceil((p(2)+1) * sampPerPix);
				if x > ns, x = ns; end;
				if x <= head+minStep, x = head+minStep; end;
			end;
			tail = x;
			
		else,	% move selection
			dx = x + mode;		% mode holds (negated) starting point
			if head+dx < 1, dx = 1-head; end;
			if tail+dx > ns, dx = ns-tail; end;
			trajState.MODE = -round(x);
			head = head + dx;
			tail = tail + dx;
		end;
		
%	update selection
		set(trajState.BOUNDS, 'XData', [head head tail tail]);
		state.HEAD = sampsToMsecs(head, trajState.FSRATE);
		state.TAIL = sampsToMsecs(tail, trajState.FSRATE);
		set(state.HEADF, 'String', fixstr(state.HEAD));
		set(state.TAILF, 'String', fixstr(state.TAIL));
		set(gcbf, 'UserData', trajState);
		set(trajState.GUI, 'UserData', state);
		

%-----------------------------------------------------------------------------
%	PLOTSAMPS:  toggle sample plotting status

	case 'PLOTSAMPS',
		[state, trajState] = FindState;
		trajState.PLOTSAMPS = umtoggle(gcbo);
		set(state.TRAJWIN, 'UserData', trajState);
		if trajState.PLOTSAMPS, s = 'on'; m = 'o'; else, s = 'off'; m = 'none'; end;
		set(state.MENUS(:,3), 'Checked', s);
		if ~trajState.INITIALIZED, return; end;	
		for p = 2 : length(trajState.PANELS),
			lines = findobj(trajState.PANELS(p), 'Tag', 'data');
			set(lines, 'marker', m);
		end;
		

%-----------------------------------------------------------------------------
%	TOGBG:  toggle background color

	case 'TOGBG',
		[state, trajState] = FindState;
		figure(state.TRAJWIN);
		if any(get(state.TRAJWIN, 'Color') < .5), newBGC = 'white'; else, newBGC = 'black'; end;
		map = get(state.TRAJWIN, 'colormap');
		clf;
		colordef(state.TRAJWIN, newBGC);
		set(state.TRAJWIN, 'colormap', map);
		if trajState.INITIALIZED, m_traj('INIT', state); end;
		

%-----------------------------------------------------------------------------
%	UP:  handle mouseUp (complete move-in-progress)

	case 'UP',
		global M_NONE M_CURS M_LABEL msecsToSamps sampsToMsecs fixstr;
		trajState = get(gcbf, 'UserData');
		state = get(trajState.GUI, 'UserData');
		mode = trajState.MODE;	
		trajState.MODE = M_NONE;
		set(gcbf, 'UserData', trajState, ...
			'WindowButtonMotionFcn', '', ...
			'WindowButtonUpFcn', '');
			
%	handle cursor movement
		if mode >= M_CURS,
			curPt = get(trajState.CURSORH, 'CurrentPoint');
			x = curPt(1,1);
			if state.CURSOR ~= x,
				state.CURSOR = x;
				set(state.CURSF, 'String', fixstr(x));
				set(trajState.GUI, 'UserData', state);
				set(trajState.CURSORL, 'XData', [x x]);
				m_spat('UPDATE', state);
			end;
			h = [state.XVALF state.YVALF state.ZVALF];
			set(h, 'String', '');
			if mode == M_LABEL, m_label('MAKE'); end;
			
%	selection change	
		else,
			if (trajState.AUTOUPDATE), Redraw(trajState); end;
			set(state.HEADF, 'String', fixstr(state.HEAD));
			set(state.TAILF, 'String', fixstr(state.TAIL));
		end;

		
%-----------------------------------------------------------------------------
%	UPDATE:  manual update

	case 'UPDATE',
		if nargin < 2,	
			set(0,'ShowHiddenHandles', 'on');
			trajWin = findobj('Tag', 'TRAJ');
			set(0,'ShowHiddenHandles', 'off');
			trajState = get(trajWin, 'UserData');
		else,			
			trajState = aux;
			global msecsToSamps;
			state = get(trajState.GUI, 'UserData');
			head = msecsToSamps(state.HEAD, trajState.FSRATE);
			tail = msecsToSamps(state.TAIL, trajState.FSRATE);
			set(trajState.BOUNDS, 'XData', [head head tail tail]);
			set(trajState.CURSORL, 'XData', [state.CURSOR state.CURSOR]);
		end;
		if ~trajState.INITIALIZED, return; end;	
		Redraw(trajState);


%-----------------------------------------------------------------------------
%	YACK:  squawk selection (framing trajectory) if monodimensional and sRate >= 500Hz

	case 'YACK',
		global msecsToSamps;
		[state, trajState] = FindState;
		if ~trajState.INITIALIZED, return; end;	
		state = get(trajState.GUI, 'UserData');
		if size(state.DATA(1).SIGNAL,2) == 1 & trajState.FSRATE >= 500,
			head = msecsToSamps(state.HEAD, trajState.FSRATE);
			tail = msecsToSamps(state.TAIL, trajState.FSRATE);
			soundsc(state.DATA(1).SIGNAL(head:tail,1), trajState.FSRATE);
		end;
		

%-----------------------------------------------------------------------------
%	error

	otherwise,
		error(['M_TRAJ:  unrecognized action (', action, ')']);
	
end;


%=============================================================================
%	FINDSTATE  - locate GUI object

function [state, trajState] = FindState

set(0,'ShowHiddenHandles', 'on');
gui = findobj('Tag', 'GUI');
set(0,'ShowHiddenHandles', 'off');
state = get(gui, 'UserData');
trajState = get(state.TRAJWIN, 'UserData');


%=============================================================================
%	REDRAW current selection

function Redraw(trajState)

global msecsToSamps;
state = get(trajState.GUI, 'UserData');

for i = 2 : length(trajState.DISPMAP)+1,
	t = trajState.DISPMAP(i-1);
	head = state.HEAD * state.DATA(t).SRATE/1000 + 1;
	tail = state.TAIL * state.DATA(t).SRATE/1000 + 1;
	set(trajState.PANELS(i), 'XLim', [head tail]);
	pos = get(trajState.TRAJLABS(i), 'Position');
	pos(1) = head;
	set(trajState.TRAJLABS(i), 'Position', pos);
end;

set(trajState.CURSORH, 'Xlim', [state.HEAD state.TAIL]);

