function m_out = ml_labelCV(action, aux, aux2, aux3)
%ML_LABELCV  - MAVIS user labelling procedure
%
% Labels the first maximum of the selected dimension left of the cursor location "C"
% and the first minimum of the selected dimension right of the cursor location "V"
% for the clicked trajectory

% 03/00 mkt

%	branch by action...

switch action,
		
%-----------------------------------------------------------------------------
% CONFIG:  handle configuration
%
%	AUX		- internal state
%
% which dimension should be tested?

	case 'CONFIG',
		state = aux;						% get internal state
		labelData = DoConfig(state.LABEL.USERDATA);
		if isempty(labelData),
			m_out = 0;				% report cancel
			return;
		end;
		state.LABEL.USERDATA = labelData;
		set(state.GUI, 'UserData', state);	% update internal state
		m_out = 1;							% report OK
		return;
		
		
%-----------------------------------------------------------------------------
% DOWN:  handle mouseDown
%
%	AUX		- internal state

	case 'DOWN',
		state = aux;
		set(state.TRAJWIN,  ...			% init handlers
			'WindowButtonMotionFcn', 'm_label MOVE;', ...
			'WindowButtonUpFcn', 'ml_labelCV UP;');


%-----------------------------------------------------------------------------
% PLOT:  plot label into the current axes
%
%	AUX		- x offset (in trajectory sample units) of label
%	AUX2	- yLim of current axis
%	AUX3	- label
%
% call the default plotting routine

	case 'PLOT',
		m_label('PLOT', aux, aux2, aux3);
		

%-----------------------------------------------------------------------------
% UP:  handle mouseUp
%
% find the extrema of clicked trajectory
% if it has less than preferred dimension use highest that it has
% dimension 3 interpreted here as sum(XY)

	case 'UP',
		set(gcbf, ...						% clear motion handlers
			'WindowButtonMotionFcn', '', ...
			'WindowButtonUpFcn', '');
		global msecsToSamps sampsToMsecs;	% map time : samples
		trajState = get(gcbf, 'UserData');	% retrieve state
		state = get(trajState.GUI, 'UserData');
		t = trajState.TRACK;				% clicked trajectory
		d = state.LABEL.USERDATA.DIM;		% preferred dimension
		
% get clicked trajectory data over the range of the current temporal selection
		sRate = state.DATA(t).SRATE;
		head = msecsToSamps(state.HEAD, sRate);
		tail = msecsToSamps(state.TAIL, sRate);
		curLoc = msecsToSamps(state.CURSOR, sRate) - head + 1;
		nDims = size(state.DATA(t).SIGNAL,2);
		if nDims==2 & d==3,					% apply to sum(XY)
			data = sum(state.DATA(t).SIGNAL(head:tail,:),2);
		else,
			if nDims < d, d = nDims; end;	% dimension
			data = state.DATA(t).SIGNAL(head:tail,d);
		end;

% find extrema
		dd = diff(data);
		minen = find(([0;dd]<0) & ([dd;0]>=0));		% find indices of minima
		maxen = find(([dd;0]<0) & ([0;dd]>=0));		% find indices of maxima

		minS = minen(find(minen>=curLoc));			% min right of cursor (V)
		if isempty(minS), minS = curLoc; end;
		minS = minS(1);
		minT = sampsToMsecs(minS+head-1, sRate);
		
		maxS = maxen(find(maxen<=curLoc));			% max left of cursor (C)
		if isempty(maxS), maxS = curLoc; end;
		maxS = maxS(end);
		maxT = sampsToMsecs(maxS+head-1, sRate);

% label
		saveAnnotate = state.LABEL.ANNOTATE;		% get current annotation status
		state.LABEL.ANNOTATE = 0;					% force it off for quiet label creation
		set(state.GUI, 'UserData', state);

		trajName = state.DATA(t).NAME;				% build name 
		if nDims > 1,
			xyz = 'XYZ';
			trajName = [trajName '_' xyz(d)]; 
		end;
		label = struct('NAME', 'C', ...
					'OFFSET', maxT, ...				
					'NOTE', [trajName ' (local max)'], ...					
					'VALUE', []);
		m_label('MAKE', label);
		label = struct('NAME', 'V', ...
					'OFFSET', minT, ...				
					'NOTE', [trajName ' (local min)'], ...					
					'VALUE', []);
		m_label('MAKE', label);
		
		state = get(state.GUI, 'UserData');			% refresh internal state
		state.LABEL.ANNOTATE = saveAnnotate;		% restore annotation status
		set(state.GUI, 'UserData', state);
		

%-----------------------------------------------------------------------------
% error

	otherwise,
		error(['ML_LABELCV:  unrecognized action (', action, ')']);
	
end;


%=============================================================================
% DOCONFIG  - config handler
%
%   returns non-empty labelData (selected dimension) on OK, empty result on cancel

function labelData = DoConfig(labelData)

figPos = get(0, 'ScreenSize');
width = 270;
height = 170;
figPos = [figPos(1)+(figPos(3)-width)/2, figPos(2)+(figPos(4)-height)/2, width, height];
if strncmp(computer, 'SGI', 3), as = 'left'; else, as = 'right'; end;	% SGI bug:  doesn't like right alignment

idString = 'ML_LABELCV';
if isempty(labelData) | ~strcmp(labelData.SOURCE, idString),		% if not previously configured
	labelData = struct('SOURCE', idString, ...
						'DIM', 1);
end;

cfg = dialog('Name', idString, ...
	'Position', figPos, ...
	'ButtonDownFcn', '', ...
	'UserData', 0);

% about
uicontrol(cfg, ...
	'Position', [10 height-80 width-20 70], ...
	'Style', 'frame');
uicontrol(cfg, ...
	'Position', [13 height-77 width-26 64], ...
	'Style', 'text', ...
	'HorizontalAlignment', 'left', ...
	'String', ['Labels the first maximum of the selected dimension left of the cursor location "C" ' ...
				'and the first minimum right of the cursor location "V" for the clicked trajectory']);

% select dimensions
uicontrol(cfg, ...
	'Position', [10 55 115 17], ...
	'HorizontalAlignment', as, ...
	'String','Apply to dimension:', ...
	'Style','text');
xRB = uicontrol(cfg, ...
	'Position', [130 55 40 20], ...
	'String','X', ...
	'Style','radiobutton', ...
	'Value', (labelData.DIM==1), ...
	'Callback', 'set(gcbo,''Value'',1);set(get(gcbo,''UserData''),''Value'',~get(gcbo,''Value''));');
yRB = uicontrol(cfg, ...
	'Position', [175 55 40 20], ...
	'String','Y', ...
	'Style','radiobutton', ...
	'Value', (labelData.DIM==2), ...
	'Callback', 'set(gcbo,''Value'',1);set(get(gcbo,''UserData''),''Value'',~get(gcbo,''Value''));');
zRB = uicontrol(cfg, ...
	'Position', [220 55 40 20], ...
	'String','XY', ...
	'Style','radiobutton', ...
	'Value', (labelData.DIM==3), ...
	'Callback', 'set(gcbo,''Value'',1);set(get(gcbo,''UserData''),''Value'',~get(gcbo,''Value''));');
set(xRB, 'UserData', [yRB zRB]);
set(yRB, 'UserData', [xRB zRB]);
set(zRB, 'UserData', [xRB yRB]);

% OK, cancel buttons
uicontrol(cfg, ...		% buttons
	'Position',[width/2-70 15 60 25], ...
	'String','OK', ...
	'Callback','set(gcbf,''UserData'',1);uiresume');
uicontrol(cfg, ...
	'Position',[width/2+10 15 60 25], ...
	'String','Cancel', ...
	'Callback','uiresume');

% wait for input
uiwait(cfg);
if get(cfg, 'UserData'),
	labelData.DIM = find([get(xRB, 'Value') get(yRB, 'Value') get(zRB, 'Value')]);
else,
	labelData = [];
end;
delete(cfg);
