function m_out = ml_colors(action, aux, aux2, aux3)
%ML_COLORS  - MAVIS user labelling procedure
%
% Works like default MAVIS label handlers, except that the contents of
% the label NOTE field are interpreted as a triphone if equal to a [1x3]
% vector of offset times.  The triphone initial and final offset are used
% to plot a triangle with its peak at the central offset.

% 01/98 mkt

%	branch by action...

switch action,
		
%-----------------------------------------------------------------------------
% CONFIG:  handle configuration
%
%	AUX		- internal state
%
% no configuration necessary, just show blurb

	case 'CONFIG',
		ShowBlurb;
		m_out = 1;					% report OK
		return;
		
		
%-----------------------------------------------------------------------------
% DOWN:  handle mouseDown
%
%	AUX		- internal state
%	AUX2	- index of clicked trajectory (into state.DATA)

	case 'DOWN',
		state = aux;
		set(state.TRAJWIN,  ...			% init motion handlers
			'WindowButtonMotionFcn', 'm_label MOVE;', ...
			'WindowButtonUpFcn', 'ml_triphones UP;');


%-----------------------------------------------------------------------------
% PLOT:  plot label into the current axes
%
%	AUX		- x offset (in trajectory sample units) of label
%	AUX2	- yLim of current axis
%	AUX3	- label

	case 'PLOT',
		x = [aux aux];
		y = aux2 * .9;
		label = aux3;
		colors = get(gca, 'ColorOrder');

% NOTE field empty or not a numeric [1x3] vector -- plot default label
		if isempty(label.NOTE) | ~isnumeric(label.NOTE) | ~all(size(label.NOTE) == [1 3]),
			line(x, y, 'Color', colors(3,:));					

% NOTE field specifies triphone offsets
		else,
			line(x, y, 'Color', colors(1,:));			% middle offset line
			x = label.NOTE*(aux-1)/label.OFFSET + 1;	% cvt to samples
			y = [y y(2)*.9];
			line([x(2) x(1) x(3) x(2)], [y(3) y(1) y(1) y(3)], ...
				'Color', colors(2,:));					% head, tail as triangle
		end;

		if ~isempty(label.NAME),
			text(x(2), y(2), [' ', label.NAME], ...
				'VerticalAlignment', 'top', ...
				'fontname', 'geneva', ...
				'fontsize', 9);
		end;
		

%-----------------------------------------------------------------------------
% UP:  handle mouseUp

	case 'UP',
		set(gcbf, ...						% clear motion handlers
			'WindowButtonMotionFcn', '', ...
			'WindowButtonUpFcn', '');
		
		label = struct('NAME', '', ...		% no name
					'OFFSET', [], ...		% use current cursor offset
					'NOTE', [], ...			% set by annotation dialog
					'VALUE', []);			% value contents ignored

		m_label('MAKE', label);				% create a standard label
		
	
%-----------------------------------------------------------------------------
% error

	otherwise,
		error(['ML_TRIPHONES:  unrecognized action (', action, ')']);
	
end;

%=============================================================================
% SHOWBLURB

function ShowBlurb

figPos = get(0, 'ScreenSize');
width = 300;
height = 170;
figPos = [figPos(1)+(figPos(3)-width)/2, figPos(2)+(figPos(4)-height)/2, width, height];

cfg = dialog('Name', 'ML_TRIPHONES', ...
	'Position', figPos, ...
	'ButtonDownFcn', '');

% about
blurb = ['Works like default MAVIS label handlers, except that the contents of ' ...
			'the label NOTE field are interpreted as a triphone if equal to a ' ...
			'[1x3] vector of offset times.  The triphone initial and final offset ' ...
			'are used to plot a triangle with its peak at the central offset.'];

uicontrol(cfg, ...
	'Position', [10 60 width-20 100], ...
	'Style', 'frame');
uicontrol(cfg, ...
	'Position', [13 63 width-26 94], ...
	'Style', 'text', ...
	'HorizontalAlignment', 'left', ...
	'String', blurb);

% OK button
uicontrol(cfg, ...		% buttons
	'Position',[width/2-30 15 60 25], ...
	'String','OK', ...
	'Callback','uiresume');

% wait for input
uiwait(cfg);
delete(cfg);
